summaryrefslogtreecommitdiffstats
path: root/kscd/libwm
diff options
context:
space:
mode:
authorDarrell Anderson <humanreadable@yahoo.com>2012-04-13 00:30:28 -0500
committerDarrell Anderson <humanreadable@yahoo.com>2012-04-13 00:30:28 -0500
commit017d437099d1f1d6a68e145eca4a507e8ab65d9e (patch)
treef7b44ebcd381527c939e70e03555105218336d76 /kscd/libwm
parent14c903d8a9e29e9505ec05ca630f1b5a218679ad (diff)
downloadtdemultimedia-017d437099d1f1d6a68e145eca4a507e8ab65d9e.tar.gz
tdemultimedia-017d437099d1f1d6a68e145eca4a507e8ab65d9e.zip
Fix inadvertent "TQ" changes.
Diffstat (limited to 'kscd/libwm')
-rw-r--r--kscd/libwm/include/wm_scsi.h2
-rw-r--r--kscd/libwm/plat_hpux.c2
-rw-r--r--kscd/libwm/scsi.c8
3 files changed, 6 insertions, 6 deletions
diff --git a/kscd/libwm/include/wm_scsi.h b/kscd/libwm/include/wm_scsi.h
index 5f11ea7e..f67e8035 100644
--- a/kscd/libwm/include/wm_scsi.h
+++ b/kscd/libwm/include/wm_scsi.h
@@ -30,7 +30,7 @@
#include "wm_struct.h"
-#define WM_ERR_SCSI_INTQUIRY_FAILED -1
+#define WM_ERR_SCSI_INQUIRY_FAILED -1
int wm_scsi_mode_sense( struct wm_drive *d, unsigned char page,
unsigned char *buf );
diff --git a/kscd/libwm/plat_hpux.c b/kscd/libwm/plat_hpux.c
index 1a12da4e..a7d3c551 100644
--- a/kscd/libwm/plat_hpux.c
+++ b/kscd/libwm/plat_hpux.c
@@ -118,7 +118,7 @@ wmcd_open( struct wm_drive *d )
/* Now fill in the relevant parts of the wm_drive structure. */
fd = d->fd;
- /* Default drive is the HP one, which might not respond to INTQUIRY */
+ /* Default drive is the HP one, which might not respond to INQUIRY */
strcpy(&vendor, "TOSHIBA");
strcpy(&model, "XM-3301");
rev[0] = '\0';
diff --git a/kscd/libwm/scsi.c b/kscd/libwm/scsi.c
index 3ab2772d..b15a286f 100644
--- a/kscd/libwm/scsi.c
+++ b/kscd/libwm/scsi.c
@@ -38,7 +38,7 @@
#include "include/wm_cdrom.h"
#include "include/wm_cdtext.h"
-#define SCMD_INTQUIRY 0x12
+#define SCMD_INQUIRY 0x12
#define SCMD_MODE_SELECT 0x15
#define SCMD_MODE_SENSE 0x1a
#define SCMD_START_STOP 0x1b
@@ -194,14 +194,14 @@ wm_scsi_mode_select( struct wm_drive *d, unsigned char *buf, unsigned char len )
}
/*
* Send an INTQUIRY command to get the drive type.
*
* d Drive structure
* vendor Buffer for vendor name (8 bytes + null)
* model Buffer for model name (16 bytes + null)
* rev Buffer for revision level (4 bytes + null)
*
* The above string lengths apply to the SCSI INTQUIRY command. The
* actual WorkMan drive structure reserves 31 bytes + NULL per entry.
*
* If the model name begins with "CD-ROM" and zero or more spaces, that will
@@ -216,7 +216,7 @@ wm_scsi_get_drive_type( struct wm_drive *d, char *vendor,
memset(buf, 0, 36);
wm_lib_message(WM_MSG_CLASS_SCSI | WM_MSG_LEVEL_INFO, "Sending SCSI inquiry command...\n");
- if (sendscsi(d, buf, 36, 1, SCMD_INTQUIRY, 0, 0, 0, 36, 0,0,0,0,0,0,0))
+ if (sendscsi(d, buf, 36, 1, SCMD_INQUIRY, 0, 0, 0, 36, 0,0,0,0,0,0,0))
{
sprintf( vendor, WM_STR_GENVENDOR);
sprintf( model, WM_STR_GENMODEL);
@@ -194,14 +194,14 @@ wm_scsi_mode_select( struct wm_drive *d, unsigned char *buf, unsigned char len )
}
/*
- * Send an INTQUIRY command to get the drive type.
+ * Send an INQUIRY command to get the drive type.
*
* d Drive structure
@@ -194,14 +194,14 @@ wm_scsi_mode_select( struct wm_drive *d, unsigned char *buf, unsigned char len )
* rev Buffer for revision level (4 bytes + null)
*
- * The above string lengths apply to the SCSI INTQUIRY command. The
+ * The above string lengths apply to the SCSI INQUIRY command. The
* actual WorkMan drive structure reserves 31 bytes + NULL per entry.
*